# Generated by Django 2.2 on 2019-07-09 15:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('anss', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='feedearthquake',
            options={'get_latest_by': ('-feed_id', '-time'), 'ordering': ('-feed_id', '-time')},
        ),
    ]
